%define version 1.3.3

Summary: Software modem for interfacing Asterisk and Hylafax via IAX2
Name: iaxmodem
Version: %{version}
Release: 1%{?dist}
License: GPL
Group: Applications/Communications
Url: https://sourceforge.net/projects/iaxmodem
Source0: http://prdownloads.sourceforge.net/iaxmodem/iaxmodem-%{version}.tar.gz
Source2: iaxmodem.logrotate.d
Source3: iaxmodem.service
Source4: iaxmodem.Quickstart
# From ansible-role-freepbx-hylafax
Source5: iaxmodem.faxgetty@.service
Source6: iaxmodem@.service
Source7: iaxmodem.faxsetup.expect
# Non usiamo, non si capisce xche
Patch0: iaxmodem-1.3.0-flattened-fast_modems.patch
# Taken from SuSE iaxmodem-1.3.3-2.7.src.rpm
Patch1: iaxmodem-config.patch
# Taken from Fedora iaxclient-2.1-0.41.beta3.fc37.src.rpm which has libiax2 too
# Fix some makefile issues
Patch20:	iax-0.2.3_makefile.patch
# Fix format-security issue
Patch21:	iax-0.2.3_format-security.patch
# Add missing #include <sys/socket.h>
Patch22:	iax-0.2.3_socket.patch
# removing -DDEBUG_SUPPORT, as in iax-0.2.3_makefile.patch, makes some needed symbols be opted-out.
Patch30:	iax-0.2.3_makefile-lux.patch
Vendor: Lee Howard <faxguy@howardsilvan.com>
Packager: Laimbock Consulting <asterisk@laimbock.com>
Buildroot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: gcc-c++
BuildRequires: libtiff-devel
BuildRequires: spandsp-devel >= 0.0.6
%if %{?fedora}0 > 140 || %{?rhel}0 > 60
BuildRequires: systemd-units
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units
%endif
# We write in /var/spool/hylafax/etc...
Requires: hylafax

%description
IAXmodem is a software modem written in C that uses an IAX channel
(commonly provided by an Asterisk PBX system) instead of a traditional
phone line and uses a DSP library instead of DSP hardware chipsets.

To accomplish this, then, IAXmodem interfaces an IAX library known as
libiax2 with a DSP library known as spandsp, and then IAXmodem interfaces
the DSP library with a tty device node for interfacing with modem
applications.

%pre
# Some distros may already ship with an existing asterisk group. Create it here
# if the group does not yet exist (with the -f flag).
%{_sbindir}/groupadd -f -r asterisk &>/dev/null || :
# At this point the asterisk group must already exist
if ! grep -q asterisk: /etc/passwd ; then
%{_sbindir}/useradd  -r -s /sbin/nologin -d /var/lib/asterisk -M \
                               -c 'Asterisk User' -g asterisk asterisk &>/dev/null || :
fi

%prep
%setup
#%patch0 -p1
%patch1 -p1
rm -r lib/spandsp

# Taken from Fedora iaxclient-2.1-0.41.beta3.fc37.src.rpm which has libiax2 too
(
cd lib/libiax2
#%patch20 -p1 -b .iaxmakefile
%patch30 -p1 -b .iaxmakefile
%patch21 -p1 -b .iaxfmtsecurity
%patch22 -p1 -b .iaxsocket

sed -i 's|${exec_prefix}/lib|${exec_prefix}/%{_lib}|g' iax-config.in
sed -i 's|/usr/lib|%{_libdir}|g' iax-config.in

autoreconf -vif
)

mv config.ttyIAX config.ttyIAX0
mv iaxmodem-cfg.ttyIAX iaxmodem-cfg.ttyIAX0
%{__install} -m0644 %{SOURCE4} ./README.Quickstart
%{__install} -m0644 %{SOURCE7} ./faxsetup.expect

%build
[ "%{buildroot}" != '/' ] && rm -rf %{buildroot}

pushd lib/libiax2
%configure --disable-shared
# Taken from Fedora iaxclient-2.1-0.41.beta3.fc37.src.rpm which has libiax2 too
%{__make} %{?_smp_mflags} UCFLAGS="%{optflags}"
popd

#pushd lib/spandsp
# % configure --disable-shared
# % {__make} %{?_smp_mflags}
#popd

# set the variables
MODEMVER=iaxmodem-%{version}
#STEP1=`grep @VERSION@ lib/spandsp/config.status | sed 's/;.*//g'`
#DSPVER=`echo "@VERSION@" | sed $STEP1`
#if [ -n "$DSPVER" ]; then
#    DSPVER="spandsp-$DSPVER-snapshot-20060707+"
#fi
DSPVER=`rpm -q --queryformat '%{NAME}-%{VERSION}' spandsp`
#STEP1=`grep @VERSION@ lib/libiax2/config.status | sed 's/;.*//g'`
#IAXVER=`echo "@VERSION@" | sed $STEP1`
IAXVER=`grep -F '["VERSION"]' lib/libiax2/config.status | sed 's/^.*="\(.*\)"/\1/'`
if [ -n "$IAXVER" ]; then
    IAXVER="libiax2-$IAXVER-CVS-20060222+"
fi

# build a static version of iaxmodem
gcc $RPM_OPT_FLAGS -Wall -g -DMODEMVER=\"$MODEMVER\" -DDSPVER=\"$DSPVER\" -DIAXVER=\"$IAXVER\" -DSTATICLIBS -D_GNU_SOURCE -std=c99 -Ilib/libiax2/src -c -o iaxmodem.o iaxmodem.c
#-Ilib/spandsp/src
#" <- just here to keep the vi syntax highlighting sane
gcc -lm -lutil -ltiff -lspandsp -o iaxmodem iaxmodem.o lib/libiax2/src/.libs/libiax.a
# lib/spandsp/src/.libs/libspandsp.a 

%install
# install the bunch manually
%{__install} -D -m 755 iaxmodem %{buildroot}%{_sbindir}/iaxmodem
%{__install} -D -m 644 iaxmodem.1 %{buildroot}%{_mandir}/man1/iaxmodem.1
%{__install} -d %{buildroot}%{_sysconfdir}/logrotate.d
%{__install} -m 644 %{SOURCE2} %{buildroot}/etc/logrotate.d/iaxmodem
%{__install} -d -m 755 %{buildroot}%{_localstatedir}/log/iaxmodem
perl -pi -e 's,/usr/local/,/usr/,g' iaxmodem.init.fedora
%if %{?fedora}0 > 140 || %{?rhel}0 > 60
install -d -m 755 %{buildroot}%{_unitdir}
install -p -m 644 %{SOURCE5} %{buildroot}%{_unitdir}/faxgetty@.service
install -p -m 644 %{SOURCE6} %{buildroot}%{_unitdir}/iaxmodem@.service
%else
install -d -m 755 %{buildroot}%{_initrddir}
%{__install} -D -m 755 iaxmodem.init.fedora %{buildroot}%{_initrddir}/iaxmodem
%endif

%post
%if %{?fedora}0 > 140 || %{?rhel}0 > 60
	%systemd_post %{name}.service
%endif


%preun
%if %{?fedora}0 > 140 || %{?rhel}0 > 60
	%systemd_preun %{name}.service
%endif

%postun
%if %{?fedora}0 > 140 || %{?rhel}0 > 60
	%systemd_postun_with_restart %{name}.service
%endif

%clean
[ "%{buildroot}" != '/' ] && rm -rf %{buildroot}

%files
%defattr(0644,root,root, 0755)
%doc CHANGES FAQ README* TODO config.ttyIAX0 iaxmodem-cfg.ttyIAX0 faxsetup.expect
%attr(750,root,root)				%{_sbindir}/iaxmodem
%attr(0644,root,root)					%{_mandir}/man1/iaxmodem.1.gz
%attr(0644,root,root)		%config(noreplace)	%{_sysconfdir}/logrotate.d/*
%attr(0755,uucp,uucp)		%dir			%{_localstatedir}/log/iaxmodem
%if %{?fedora}0 > 140 || %{?rhel}0 > 60
%attr(0644,root,root) %{_unitdir}/*.service
%else
%attr(0755,root,root)					%{_initrddir}/iaxmodem
%endif

%changelog
* Mon Jun 20 2022 Luigi Iotti <asterisk@iotti.biz> - 1.3.3-1
- Update to 1.3.3
- First lux version

* Tue Dec 26 2017 Nicolás Gudiño <nicolas@issabel.com> - 1.3.0-2
- Create asterisk user and group if needed. Bump release number

* Wed Oct 11 2017 Nicolás Gudiño <nicolas@issabel.com> - 1.3.0-1
- Do not require Asterisk in RPM 

* Mon Nov 21 2016 Alex Villacis Lasso <a_villacis@palosanto.com> 1.3.0-0
- Update to 1.3.0
- Patch to build with system spandsp
- Fix executable permissions on /usr/sbin/iaxmodem

* Thu Apr 05 2012 Alex Villacis Lasso <a_villacis@palosanto.com> 1.2.0-2
- BuildRequires: gcc-c++

* Wed May 13 2009 Alex Villacis Lasso <a_villacis@palosanto.com> 1.2.0-1.1
- Rename samples for real, include fixup for previous attempt.

* Tue May 12 2009 Alex Villacis Lasso <a_villacis@palosanto.com> 1.2.0-1
- Rename sample configuration files so that iaxmodem will not attempt to start
  with a bogus configuration. Prevents filling-up of Asterisk log with failed
  attempts with said bogus configuration.

* Fri May 08 2009 Alex Villacis Lasso <a_villacis@palosanto.com> 1.2.0-0
- Update to 1.2.0

* Thu Aug 17 2006 Laimbock Consulting <asterisk@laimbock.com> 0.1.14-1
- inital spec file based on 0.1.14
- static build so it does not interfere with spandsp

